@@ -4,16 +4,15 @@ from plone.dexterity.browser.add import DefaultAddView
 
 
 class AddForm(DefaultAddForm):
-
     def updateFields(self):
-        ''' Adds a referer to be used when a cancel button is pressed
-        '''
+        """Adds a referer to be used when a cancel button is pressed"""
         super(AddForm, self).updateFields()
         self.fields = self.fields.omit(
-            'login', 'password', 'locked', 'contact_name', 'contact_email')
+            "login", "password", "locked", "contact_name", "contact_email"
+        )
 
 
 class AddView(DefaultAddView):
-    ''' Custom form for adding a euphorie sector
-    '''
+    """Custom form for adding a euphorie sector"""
+
     form = AddForm
