@@ -9,11 +9,11 @@ grok.templatedir("templates")
 
 class OSHASettings(Settings):
     grok.layer(IProductLayer)
-    grok.name('edit')
-    grok.template('settings')
+    grok.name("edit")
+    grok.template("settings")
 
     def extractData(self):
-        unwanted_fields = ('locked', 'password', 'contact_name', 'contact_email')
+        unwanted_fields = ("locked", "password", "contact_name", "contact_email")
         self.fields = self.fields.omit(*unwanted_fields)
         for key in unwanted_fields:
             if key in self.widgets:
